=====
TkMVC
=====


.. image:: https://img.shields.io/pypi/v/tkmvc.svg
        :target: https://pypi.python.org/pypi/tkmvc

.. image:: https://img.shields.io/travis/unodan/tkmvc.svg
        :target: https://travis-ci.org/unodan/tkmvc

.. image:: https://readthedocs.org/projects/tkmvc/badge/?version=latest
        :target: https://tkmvc.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




TkMVC is a Model-View-Controller Framework base on the Tkinter GUI toolset.


* Free software: MIT license
* Documentation: https://tkmvc.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
